==> jwinner-base-0.1.0-sources.jar: itez/plat/site/model/base/BaseContent.java <==
package itez.plat.site.model.base;

import itez.core.wrapper.dbo.model.EModel;
import com.jfinal.plugin.activerecord.IBean;

/**
 * 由JWinner Model Generator自动生成，请勿修改本文件。
 */
@SuppressWarnings({"serial", "unchecked"})
public abstract class BaseContent<M extends BaseContent<M>> extends EModel<M> implements IBean {

	public M setId(java.lang.String id) {
		set("id", id);
		return (M)this;
	}
	
	public java.lang.String getId() {
		return getStr("id");
	}

	public M setDomain(java.lang.String domain) {
		set("domain", domain);
		return (M)this;
	}
	
	public java.lang.String getDomain() {
		return getStr("domain");
	}

	public M setChannelId(java.lang.String channelId) {
		set("channelId", channelId);
		return (M)this;
	}
	
	public java.lang.String getChannelId() {
		return getStr("channelId");
	}

	public M setPic(java.lang.String pic) {
		set("pic", pic);
		return (M)this;
	}
	
	public java.lang.String getPic() {
		return getStr("pic");
	}

	public M setCaption(java.lang.String caption) {
		set("caption", caption);
		return (M)this;
	}
	
	public java.lang.String getCaption() {
		return getStr("caption");
	}

	public M setSubCaption(java.lang.String subCaption) {
		set("subCaption", subCaption);
		return (M)this;
	}
	
	public java.lang.String getSubCaption() {
		return getStr("subCaption");
	}

	public M setSummary(java.lang.String summary) {
		set("summary", summary);
		return (M)this;
	}
	
	public java.lang.String getSummary() {
		return getStr("summary");
	}

	public M setAuthor(java.lang.String author) {
		set("author", author);
		return (M)this;
	}
	
	public java.lang.String getAuthor() {
		return getStr("author");
	}

	public M setContent(java.lang.String content) {
		set("content", content);
		return (M)this;
	}
	
	public java.lang.String getContent() {
		return getStr("content");
	}

	public M setCdate(java.util.Date cdate) {
		set("cdate", cdate);
		return (M)this;
	}
	
	public java.util.Date getCdate() {
		return get("cdate");
	}

	public M setMdate(java.util.Date mdate) {
		set("mdate", mdate);
		return (M)this;
	}
	
	public java.util.Date getMdate() {
		return get("mdate");
	}

	public M setSort(java.lang.Integer sort) {
		set("sort", sort);
		return (M)this;
	}
	
	public java.lang.Integer getSort() {
		return getInt("sort");
	}

	public M setUsed(java.lang.Integer used) {
		set("used", used);
		return (M)this;
	}
	
	public java.lang.Integer getUsed() {
		return getInt("used");
	}

}

==> jwinner-base-0.1.7-sources.jar: itez/plat/site/model/base/BaseContent.java <==
package itez.plat.site.model.base;

import itez.core.wrapper.dbo.model.EModel;
import com.jfinal.plugin.activerecord.IBean;

/**
 * 由JWinner Model Generator自动生成，请勿修改本文件。
 */
@SuppressWarnings({"serial", "unchecked"})
public abstract class BaseContent<M extends BaseContent<M>> extends EModel<M> implements IBean {

	public M setId(java.lang.String id) {
		set("id", id);
		return (M)this;
	}
	
	public java.lang.String getId() {
		return getStr("id");
	}

	public M setDomain(java.lang.String domain) {
		set("domain", domain);
		return (M)this;
	}
	
	public java.lang.String getDomain() {
		return getStr("domain");
	}

	public M setSubDomain(java.lang.String subDomain) {
		set("subDomain", subDomain);
		return (M)this;
	}
	
	public java.lang.String getSubDomain() {
		return getStr("subDomain");
	}

	public M setChannelId(java.lang.String channelId) {
		set("channelId", channelId);
		return (M)this;
	}
	
	public java.lang.String getChannelId() {
		return getStr("channelId");
	}

	public M setPic(java.lang.String pic) {
		set("pic", pic);
		return (M)this;
	}
	
	public java.lang.String getPic() {
		return getStr("pic");
	}

	public M setThum(java.lang.String thum) {
		set("thum", thum);
		return (M)this;
	}
	
	public java.lang.String getThum() {
		return getStr("thum");
	}

	public M setCaption(java.lang.String caption) {
		set("caption", caption);
		return (M)this;
	}
	
	public java.lang.String getCaption() {
		return getStr("caption");
	}

	public M setSubCaption(java.lang.String subCaption) {
		set("subCaption", subCaption);
		return (M)this;
	}
	
	public java.lang.String getSubCaption() {
		return getStr("subCaption");
	}

	public M setSummary(java.lang.String summary) {
		set("summary", summary);
		return (M)this;
	}
	
	public java.lang.String getSummary() {
		return getStr("summary");
	}

	public M setAuthor(java.lang.String author) {
		set("author", author);
		return (M)this;
	}
	
	public java.lang.String getAuthor() {
		return getStr("author");
	}

	public M setContent(java.lang.String content) {
		set("content", content);
		return (M)this;
	}
	
	public java.lang.String getContent() {
		return getStr("content");
	}

	public M setCaptionColor(java.lang.String captionColor) {
		set("captionColor", captionColor);
		return (M)this;
	}
	
	public java.lang.String getCaptionColor() {
		return getStr("captionColor");
	}

	public M setLink(java.lang.String link) {
		set("link", link);
		return (M)this;
	}
	
	public java.lang.String getLink() {
		return getStr("link");
	}

	public M setCdate(java.util.Date cdate) {
		set("cdate", cdate);
		return (M)this;
	}
	
	public java.util.Date getCdate() {
		return get("cdate");
	}

	public M setMdate(java.util.Date mdate) {
		set("mdate", mdate);
		return (M)this;
	}
	
	public java.util.Date getMdate() {
		return get("mdate");
	}

	public M setSort(java.lang.Integer sort) {
		set("sort", sort);
		return (M)this;
	}
	
	public java.lang.Integer getSort() {
		return getInt("sort");
	}

	public M setUsed(java.lang.Integer used) {
		set("used", used);
		return (M)this;
	}
	
	public java.lang.Integer getUsed() {
		return getInt("used");
	}

}
